package
Version:
v0.0.0-...-ba70d0f
Opens a new window with list of versions in this module.
Published: Apr 16, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package pg implement database driver for PostgreSQL using pgxpool
type Driver[T any] struct {
}
Driver is a PostgreSQL driver that implements db.Driver interface.
New creates a new PostgreSQL driver instance.
Query executes a SQL query and returns the result as db.Rows.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.